#ifndef __GCAL2TXT_H
# define __GCAL2TXT_H
/*
*  gcal2txt.h:  Create a verbatim text file
*               from a Gcal resource file header file.
*
*
*  Copyright (c) 1996, 1997, 2000 Thomas Esken
*
*  This software doesn't claim completeness, correctness or usability.
*  On principle I will not be liable for ANY damages or losses (implicit
*  or explicit), which result from using or handling my software.
*  If you use this software, you agree without any exception to this
*  agreement, which binds you LEGALLY !!
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the `GNU General Public License' as published by
*  the `Free Software Foundation'; either version 3, or (at your option)
*  any later version.
*
*  You should have received a copy of the `GNU General Public License'
*  along with this program; if not, write to the:
*
*/



/*
*  $Id: gcal2txt.h 2.06 2000/06/14 02:00:06 tom Exp $
*/



/*
*  GLOBAL functions prototypes.
*/
__BEGIN_DECLARATIONS extern int main __P_ ((int argc, char *argv[]));
__END_DECLARATIONS
#endif /* __GCAL2TXT_H */
